# -*- coding: utf-8 -*-
__name__ = 'asv_seo'
__version__ = 'dev-20110618-03'
__keywords__ = 'django asv seo'
__description__ = '''
This is a title, keywords, descriptions connecting to any django model by ContentTypes.
'''
__all__ = []

#import os
#if os.getenv('DJANGO_SETTINGS_MODULE'): 
#    from asv_imgs.settings import Settings
#    settings = Settings()
#
